==> kjy-center-api-0.0.2.44-20190417.110628-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/tag/RemoteTagService.java <==
package cn.com.duiba.kjy.api.remoteservice.tag;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.tag.TagAddDto;
import cn.com.duiba.kjy.api.dto.tag.TagDetailDto;
import cn.com.duiba.kjy.api.dto.tag.TagDto;

import java.util.List;

/**
 * 标签相关服务
 * @author zhanghuifeng
 * date 2019-04-10-11:46
 */
@AdvancedFeignClient
public interface RemoteTagService {

    /**
     * 添加
     * @param tagAddDto
     * @return
     */
    Boolean add(TagAddDto tagAddDto);

    /**
     * 删除
     * @param id
     * @return
     */
    Boolean delete(Long id);

    /**
     * 编辑
     * @param tagDto
     * @return
     */
    Boolean update(TagDto tagDto);

    /**
     * 查询标签详细信息
     * @param id
     * @return
     */
    TagDetailDto findDetail(Long id);

    /**
     * 根据上级标签ID获取下级标签列表数据
     * @param parentTagId
     * @return
     */
    List<TagDto> findByParentTagId(Long parentTagId);

    /**
     * 获取下级标签数量
     * @param parentTagId
     * @return
     */
    long countByParentTagId(Long parentTagId);

    /**
     * 获取存在下级标签的上级标签ID集合
     * @param parentTagIds
     * @return
     */
    List<Long> findExitsLowTag(List<Long> parentTagIds);

    /**
     * 查询
     * @param id
     * @return
     */
    TagDto findById(Long id);

    /**
     * 获取所有标签信息
     * @return
     */
    List<TagDto> findAll();

    /**
     * 根据标签分类和级别查询
     * @param tagType
     * @return
     */
    List<TagDto> findByTagTypeAndLevel(String tagType, Integer tagLevel);

    /**
     * 根据标签级别查询
     * @param tagLevel
     * @return
     */
    List<TagDto> findByTagLevel(Integer tagLevel);

    List<TagDto> findByType(String type);
}

==> kjy-center-api-0.8.89-pre-1.0.1-20200622.092549-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/tag/RemoteTagService.java <==
package cn.com.duiba.kjy.api.remoteservice.tag;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.tag.TagAddDto;
import cn.com.duiba.kjy.api.dto.tag.TagDetailDto;
import cn.com.duiba.kjy.api.dto.tag.TagDto;

import java.util.List;
import java.util.Map;

/**
 * 标签相关服务
 * @author zhanghuifeng
 * date 2019-04-10-11:46
 */
@AdvancedFeignClient
public interface RemoteTagService {

    /**
     * 添加
     * @param tagAddDto
     * @return
     */
    Boolean add(TagAddDto tagAddDto);

    /**
     * 删除
     * @param id
     * @return
     */
    Boolean delete(Long id);

    /**
     * 编辑
     * @param tagDto
     * @return
     */
    Boolean update(TagDto tagDto);

    /**
     * 查询标签详细信息
     * @param id
     * @return
     */
    TagDetailDto findDetail(Long id);

    /**
     * 根据上级标签ID获取下级标签列表数据
     * @param parentTagId
     * @return
     */
    List<TagDto> findByParentTagId(Long parentTagId);

    /**
     * 根据上级标签ID获取下级标签列表数据
     * @param parentTagIds
     * @return
     */
    Map<Long,List<TagDto>> getParentTagId2LowerTagListMap(List<Long> parentTagIds);

    /**
     * 获取下级标签数量
     * @param parentTagId
     * @return
     */
    long countByParentTagId(Long parentTagId);

    /**
     * 获取存在下级标签的上级标签ID集合
     * @param parentTagIds
     * @return
     */
    List<Long> findExitsLowTag(List<Long> parentTagIds);

    /**
     * 查询
     * @param id
     * @return
     */
    TagDto findById(Long id);

    /**
     * 根据主键查询列表
     * @param ids
     * @return
     */
    List<TagDto> findByIds(List<Long> ids);

    /**
     * 获取所有标签信息
     * @return
     */
    List<TagDto> findAll();

    /**
     * 根据标签分类和级别查询
     * @param tagType
     * @return
     */
    List<TagDto> findByTagTypeAndLevel(String tagType, Integer tagLevel);

    /**
     * 根据标签级别查询
     * @param tagLevel
     * @return
     */
    List<TagDto> findByTagLevel(Integer tagLevel);

    List<TagDto> findByType(String type);
	
    /**
     * 批量查询
     * @param ids
     * @return
     */
    List<TagDto> listByIds(List<Long> ids);

    /**
     * 根据标签类型 查询标签id列表
     * @param tagType 标签类型
     * @see cn.com.duiba.kjy.api.enums.TagTypeEnum
     * @return
     */
    List<Long> findIdsByTagType(String tagType);
}
